#!/usr/bin/env ruby
require 'optparse'
require 'byebug'

Options = Struct.new(:app)
options = {}
args = Options.new

OptionParser.new do |opts|
  opts.banner = "Usage: kube_talk.rb [options]"

  opts.on("-l", "--logs", "Tail logs for current branch's deployment") do |l|
    options[:logs] = l
  end
  opts.on("-s", "--shell", "Shell into current branch's deployment") do |l|
    options[:shell] = l
  end
  opts.on("-w", "--web", "Open a web browser on the landing page of the app") do |l|
    options[:web] = l
  end

  opts.on("-aAPP_NAME", "--app=APP_NAME", "specify app name") do |l|
    args.app = l
  end

end.parse!

def current_deployment(app_name, feature)
  val = `HTTPS_PROXY=localhost:8888 kubectl get pods -A | grep -E "^#{app_name}" | grep "\s#{app_name}-#{feature}-" | grep Running | awk '{print $2}'`.chomp
  val
end

def current_pg(app_name, feature)
  "pg-#{app_name}-#{feature}-0"
end

def current_app(default)
  default || Dir.pwd.gsub(/[\s_]/, '-').split('/').last
end

def feature
  `git rev-parse --abbrev-ref HEAD`.split('/').last.chomp
end

def browser(url)
  if `uname -s`.match 'Linux'
    if File.exist?("/usr/bin/firefox")
      system("firefox #{url}")
    elsif File.exist?("/usr/bin/chromium")
      system("chromium #{url}")
    end
  elsif `uname -s`.match 'Darwin'
    system("open #{url}")
  else
    puts "URL to open : #{url}"
  end
end

if options[:logs]
  puts "Logs for #{current_deployment(current_app(args.app), feature)}"
  system("HTTPS_PROXY=localhost:8888 kubectl logs --follow --namespace=#{current_app(args.app)} #{current_deployment(current_app(args.app), feature)}")
  exit 0
end

if options[:shell]
  puts "Shell for #{current_deployment(current_app(args.app), feature)}"
  system("HTTPS_PROXY=localhost:8888 kubectl exec -ti --namespace=#{current_app(args.app)} #{current_deployment(current_app(args.app), feature)} -- /bin/sh")
  exit 0
end

if options[:web]
  unless ENV['GCP_DOMAIN']
    puts "Missing domain name in $GCP_DOMAIN"
    exit 1
  end
  puts "Web browser for #{current_deployment(current_app(args.app), feature)}"
  url = "https://#{feature}-#{current_app(args.app)}.#{ENV['GCP_DOMAIN']}"
  browser(url)
end
