def get_traefik_ip
  `HTTPS_PROXY=localhost:8888 kubectl -n traefik get services | grep traefik | grep pending | awk '{ print $4 }'`
end

if ENV['GCE_PROJECT'] && ENV['GCE_DOMAIN'] && ENV['DNS_EMAIL'] && ENV['GCE_REGION']
  if !File.exist?('traefik-service-account.json')
    puts "File traefik-service-account.json is missing"
    exit 1
  end

  if !File.exist?('traefik.htpass')
    puts "File traefik.htpass is missing"
    exit 1
  end
  puts "Get credentials"
  system("gcloud container clusters get-credentials app-cluster --region #{ENV['GCE_REGION']}")

  puts "Create namespace in cluster"
  system("HTTPS_PROXY=localhost:8888 kubectl create namespace traefik")

  puts "Handle the custom resource definitions"
  system("HTTPS_PROXY=localhost:8888 kubectl apply -f crd.yml")

  puts "Handle the Role-Based Access Control needed by traefik"
  system("HTTPS_PROXY=localhost:8888 kubectl apply -f rbac.yml")

  puts "Create kubernetes secrets for traefik"
  system("HTTPS_PROXY=localhost:8888 kubectl create secret generic traefik-auth --from-file traefik.htpass --namespace=traefik")
  system("HTTPS_PROXY=localhost:8888 kubectl create secret generic traefik-service-account --from-file=traefik-service-account.json=traefik-service-account.json --namespace=traefik")

  puts "Deploy traefik itself"
  system("envsubst < deployment_base.yml > deployment.yml")
  system("HTTPS_PROXY=localhost:8888 kubectl apply -f deployment.yml")

  puts "Waiting for traefik load balancer's public ip address"
  while !get_traefik_ip.match /[0-9]?[0-9]?[0-9]\.[0-9]?[0-9]?[0-9]\.[0-9]?[0-9]?[0-9]\.[0-9]?[0-9]?[0-9]/ do
    puts "... still waiting"
    sleep 5
  end
  puts "The public IP is #{get_traefik_ip}"
  puts "You probably want to add it to your DNS config :    *.#{ENV['GCE_DOMAIN']}    A    #{get_traefik_ip}"
else
  puts "Missing env vars, did you define GCE_PROJECT, GCE_DOMAIN, GCE_REGION and DNS_EMAIL ?"
  exit 1
end